@@ -12,7 +12,8 @@
 #' @param ... Additional parameters to be passed through to \link{approx} or \link{spline} interpolation functions
 #' @return Vector (\code{\link{vector}}) or Time Series (\code{\link{ts}}) object (dependent on given input at parameter x)
 #' 
-#' @details Missing values get replaced by values of a \link{approx}, \link{spline} or \link[stinepack]{stinterp} interpolation.
+#' @details Missing values get replaced by values of a \link{approx}, \link{spline} or \link[stinepack]{stinterp} interpolation. 
+#'  
 #'  
 #' @author Steffen Moritz
 #' @seealso  \code{\link[imputeTS]{na.kalman}}, \code{\link[imputeTS]{na.locf}},
@@ -39,49 +40,75 @@
 #' @import stinepack
 #' @export
 
-
 na.interpolation <- function(x, option = "linear", ...) { 
   
+  
   data <- x
   
-  #Check for wrong input 
-  data <- precheck(data)
-  
-  #if no missing data, do nothing
-  if(!anyNA(data)) {
+  # Multivariate Input Handling (loop through all columns)
+  # No imputation code in this part. 
+  if (!is.null( dim(data)[2]) && dim(data)[2] != 1  ) {
+    for (i in 1:dim(data)[2]) {
+      #if imputing a column does not work (mostly because it is not numeric) the column is left unchanged
+      tryCatch(data[,i] <- na.interpolation(data[ ,i], option), error=function(cond) {
+        warning(paste("imputeTS: No imputation performed for column",i,"because of this",cond), call. = FALSE)
+      })
+    }
     return(data)
   }
   
-  ##
-  ## Imputation Code
-  ##
-  missindx <- is.na(data)  
-  
-  n <- length(data)
-  
-  allindx <- 1:n
-  indx <- allindx[!missindx]
-  
-  if(option =="linear") {
-    interp <- as.ts(approx(indx,data[indx],1:n, rule=2, ...)$y)
-  }
-  else if(option == "spline") {
-    interp <- as.ts(spline(indx,data[indx],n = n, ... )$y)
-  }
-  else if(option == "stine") {
-    interp <- as.ts(stinterp(indx,data[indx],1:n, ...)$y)
-    #avoid NAs at the beginning and end of series // same behavior like for approx with rule = 2.
-    if(any(is.na(interp))) {interp <- na.locf(interp, na.remaining= "rev")}
-  }
+  # Univariate Input
+  # All imputation code is within this part
   else {
-    stop("Wrong parameter 'option' given. Value must be either 'linear' or 'spline'.")
-  }
-  
-  for (i in 1:length(data)) {
-    if (is.na(data[i])) {
-      data[i] <- interp[i]
+    
+    ##
+    ## Input check
+    ## 
+    
+    #if no missing data, do nothing
+    if(!anyNA(data)) {
+      return(data)
     }
-  }
+    
+    if(!is.numeric(data))
+    {stop("Input x is not numeric")}
+    
+    if(!is.null(dim(data)))
+    {stop("Wrong input type for parameter x")}
   
-  return(data)
-}
\ No newline at end of file
+    ##
+    ## Imputation Code
+    ##
+    missindx <- is.na(data)  
+    
+    n <- length(data)
+    
+    allindx <- 1:n
+    indx <- allindx[!missindx]
+    
+    if(option =="linear") {
+      interp <- as.ts(approx(indx,data[indx],1:n, rule=2, ...)$y)
+    }
+    else if(option == "spline") {
+      interp <- as.ts(spline(indx,data[indx],n = n, ... )$y)
+    }
+    else if(option == "stine") {
+      interp <- as.ts(stinterp(indx,data[indx],1:n, ...)$y)
+      #avoid NAs at the beginning and end of series // same behavior like for approx with rule = 2.
+      if(any(is.na(interp))) {interp <- na.locf(interp, na.remaining= "rev")}
+    }
+    else {
+      stop("Wrong parameter 'option' given. Value must be either 'linear' or 'spline'.")
+    }
+    
+    for (i in 1:length(data)) {
+      if (is.na(data[i])) {
+        data[i] <- interp[i]
+      }
+    }
+    
+    return(data)
+  }
+}
+
+
